@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2021 HH Partners
+//
+// SPDX-License-Identifier: MIT
+
 use std::io;
 use thiserror::Error;
 
@@ -21,6 +25,9 @@ pub enum SpdxError {
         source: reqwest::Error,
     },
 
+    #[error("Error parsing an SPDX Expression: {0}")]
+    Parse(String),
+
     #[error("Path {0} doesn't have an extension.")]
     PathExtension(String),
 
@@ -29,4 +36,13 @@ pub enum SpdxError {
         #[from]
         source: io::Error,
     },
+
+    #[error("Error while parsing date.")]
+    DateTimeParse {
+        #[from]
+        source: chrono::ParseError,
+    },
+
+    #[error("Error parsing tag-value: {0}")]
+    TagValueParse(String),
 }
